@@ -13,7 +13,8 @@ __all__ = [
     "MakeCascadeFileOp",
     "VideoToFramesOp",
     "HaarFromFramesOp",
-    "QueryDBOp",
+    "QueryDatabaseOutputDataOp",
+    "QueryDatabaseOutputStringOp",
 ]
 
 AddPyOp = load_component_from_file(
@@ -32,6 +33,12 @@ HaarFromFramesOp = load_component_from_file(
     os.path.join(os.path.dirname(__file__), "haar_from_frames/component.yaml")
 )
 
-QueryDBOp = load_component_from_file(
-    os.path.join(os.path.dirname(__file__), "query_db/component.yaml")
+QueryDatabaseOutputDataOp = load_component_from_file(
+    os.path.join(os.path.dirname(__file__), "query_database_output_data/component.yaml")
+)
+
+QueryDatabaseOutputStringOp = load_component_from_file(
+    os.path.join(
+        os.path.dirname(__file__), "query_database_output_string/component.yaml"
+    )
 )
