@@ -1,5 +1,6 @@
 import argparse
 
+
 def _add(args):
     answer = args.a + args.b
     print(answer)
@@ -8,7 +9,7 @@ def _add(args):
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
-    parser.add_argument('--a', type=int)
-    parser.add_argument('--b', type=int)
+    parser.add_argument("--a", type=int)
+    parser.add_argument("--b", type=int)
     args = parser.parse_args()
     _add(args)
