@@ -1,5 +1,6 @@
 import os
 import argparse
+from pathlib import Path
 import pandas as pd
 
 
@@ -13,18 +14,9 @@ def filter_cascades(cascade_ids):
     return filtered_cascades
 
 
-def write_cascade_df(df, save_to_gcs: bool, output_dir: str, output_filename: str):
-    save_root = ""
-    if save_to_gcs:
-        save_root += "/gcs/"
-    save_dir = f"{save_root}{output_dir}"
-    if len(save_dir) > 0:
-        save_path = f"{save_dir}/{output_filename}"
-        os.makedirs(save_dir, exist_ok=True)
-    else:
-        save_path = output_filename
-    print(f"save_path: {save_path}")
-    df.to_csv(save_path, index=False)
+def write_cascade_df(df, output_path):
+    Path(output_path).parent.mkdir(parents=True, exist_ok=True)
+    df.to_csv(output_path, index=False)
 
 
 def str2bool(v):
@@ -41,19 +33,7 @@ def str2bool(v):
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
     parser.add_argument(
-        "--save_to_gcs",
-        type=str2bool,
-        help="Whether to save the file to gcs or not",
-        default=False,
-    )
-    parser.add_argument(
-        "--output_dir",
-        type=str,
-        help="Directory to save cascades to",
-        required=True,
-    )
-    parser.add_argument(
-        "--output_filename",
+        "--output_path",
         type=str,
         help="File to save cascades to",
         required=True,
@@ -64,11 +44,19 @@ if __name__ == "__main__":
         help="List of IDs to filter the cascade file down to of the format '1,2,3'",
         required=True,
     )
+    parser.add_argument(
+        "--cascade_dataframe",
+        type=str,
+        help="Another file to save cascades to",
+        required=True,
+    )
     args = parser.parse_args()
     df = filter_cascades(args.cascade_ids)
     write_cascade_df(
         df,
-        save_to_gcs=args.save_to_gcs,
-        output_dir=args.output_dir,
-        output_filename=args.output_filename,
+        output_path=args.output_path,
+    )
+    write_cascade_df(
+        df,
+        output_path=args.cascade_dataframe,
     )
